Developer Guide
=================

This guide is mainly directed at developers working on the MetaSynth package, but it may be useful for users that want
more control over the workings of the MetaSynth package.

.. toctree::
   :maxdepth: 1
   :caption: Sections:
   
   contributing
   detailed_overview